@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 use LWP::UserAgent;
@@ -68,7 +68,8 @@ sub spawn {
 
 sub _start {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
-
+    $self->{session_id} = $_[SESSION]->ID();
+    
     if  ( $self->{alias} ) {
         $kernel->alias_set( $self->{alias} );
     }
@@ -151,7 +152,7 @@ sub _shutdown {
     my ( $kernel, $self ) = @_[ KERNEL, OBJECT ];
     $kernel->alarm_remove_all;
     $kernel->alias_remove( $_ ) for $kernel->alias_list;
-    $kernel->refcount_decrement( $self => __PACKAGE__ )
+    $kernel->refcount_decrement( $self->{session_id} => __PACKAGE__ )
         unless $self->{alias};
 
     $self->{shutdown} = 1;
